@@ -5,7 +5,7 @@
 **
 ** Comments: Dump ARP / RARP header information
 **
-** $Id: arp.c,v 1.13 2001/01/17 00:29:45 mborella Exp $
+** $Id: arp.c,v 1.14 2001/04/02 17:41:01 mborella Exp $
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -126,6 +126,12 @@ void dump_arp(packet_t *pkt)
 {
   arp_header_t arp;
 
+  /*
+   * Stats accounting
+   */
+
+  stats_update(STATS_ARP);
+
   /*
    * Get the ARP fixed header
    */
